@@ -4,7 +4,7 @@ use warnings;
 
 # ABSTRACT: Yet another xkcd style password generator
 
-our $VERSION = '1.007';
+our $VERSION = '1.008';
 
 use Carp qw(croak);
 use Crypt::Rijndael;
@@ -120,7 +120,7 @@ sub xkcd {
         push(
             @$words,
             sprintf(
-                '%0' . $d . 'd',
+                '%0' . $d . 'u',
                 with_entropy_source(
                     $self->entropy, sub { rand_int( 10**$d ) }
                 )
@@ -150,7 +150,7 @@ CtrlO::Crypt::XkcdPassword - Yet another xkcd style password generator
 
 =head1 VERSION
 
-version 1.007
+version 1.008
 
 =head1 SYNOPSIS
 
